@@ -9,6 +9,7 @@ from .button import Button
 from .dropdown import Dropdown
 from .html import Html
 from .icon import Icon
+from .iframe import IFrame
 from .link import Link
 from .toggle import Toggle
 from .message import Message, MessageButton
@@ -30,4 +31,5 @@ from .image import Image
 from .linechart import LineChart
 from .piechart import PieChart
 from .datepicker import DatePicker
-from .pglet import *
\ No newline at end of file
+from .pglet import *
+from .reconnecting_websocket import *
\ No newline at end of file
